# Koalak

Koalak is a collections of tools that helps me create my libraries, the library focus on creating plugins architectures.
The project is currently under development, I shared the repository because it is used by my tool **wordlistools**.

Koala features

- Manage plugins for your project, more information on the wiki.
- Argparse wrapper to create CLI interfaces with subcommands easily
